@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 1999-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 1999-2016 Horde LLC
+ * @copyright 1999-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Mime
  */
@@ -17,7 +17,7 @@
  * @author    Chuck Hagenbuch <chuck@horde.org>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 1999-2016 Horde LLC
+ * @copyright 1999-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Mime
  */
@@ -1765,8 +1765,7 @@ implements ArrayAccess, Countable, RecursiveIterator, Serializable
         }
 
         try {
-            reset($data);
-            while (list(,$d) = each($data)) {
+            foreach ($data as $d) {
                 if (is_resource($d)) {
                     rewind($d);
                     while (!feof($d)) {
